@@ -1,5 +1,5 @@
 /* assuan-client.c - client functions
- *	Copyright (C) 2001, 2002 Free Software Foundation, Inc.
+ *	Copyright (C) 2001, 2002, 2005 Free Software Foundation, Inc.
  *
  * This file is part of Assuan.
  *
@@ -32,12 +32,12 @@
 #define xtoi_2(p)   ((xtoi_1(p) * 16) + xtoi_1((p)+1))
 
 
-AssuanError
+assuan_error_t
 _assuan_read_from_server (ASSUAN_CONTEXT ctx, int *okay, int *off)
 {
   char *line;
   int linelen;
-  AssuanError rc;
+  assuan_error_t rc;
 
   *okay = 0;
   *off = 0;
@@ -126,24 +126,27 @@ _assuan_read_from_server (ASSUAN_CONTEXT ctx, int *okay, int *off)
  * the one one returned by the server in error lines or from the
  * callback functions.
  **/
-AssuanError
+assuan_error_t
 assuan_transact (ASSUAN_CONTEXT ctx,
                  const char *command,
-                 AssuanError (*data_cb)(void *, const void *, size_t),
+                 assuan_error_t (*data_cb)(void *, const void *, size_t),
                  void *data_cb_arg,
-                 AssuanError (*inquire_cb)(void*, const char *),
+                 assuan_error_t (*inquire_cb)(void*, const char *),
                  void *inquire_cb_arg,
-                 AssuanError (*status_cb)(void*, const char *),
+                 assuan_error_t (*status_cb)(void*, const char *),
                  void *status_cb_arg)
 {
   int rc, okay, off;
-  unsigned char *line;
+  char *line;
   int linelen;
 
   rc = assuan_write_line (ctx, command);
   if (rc)
     return rc;
 
+  if (*command == '#' || !*command)
+    return 0; /* Don't expect a response for a comment line.  */
+
  again:
   rc = _assuan_read_from_server (ctx, &okay, &off);
   if (rc)
@@ -164,7 +167,7 @@ assuan_transact (ASSUAN_CONTEXT ctx,
         rc = ASSUAN_No_Data_Callback;
       else 
         {
-          unsigned char *s, *d;
+          char *s, *d;
 
           for (s=d=line; linelen; linelen--)
             {
